! *****************************************************************
!
! This file contains a Fortran 90 module for computing the x- and 
! y-directed wind stresses
!
! Copyright (C) 2009 David McInerney, University of Chicago
!
! *****************************************************************
!
!    This program is free software: you can redistribute it and/or modify
!    it under the terms of the GNU General Public License as published by
!    the Free Software Foundation, either version 3 of the License, or
!    any later version.
!
!    This program is distributed in the hope that it will be useful,
!    but WITHOUT ANY WARRANTY; without even the implied warranty of
!    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!    GNU General Public License for more details.
!
!    You should have received a copy of the GNU General Public License
!    along with this program (see file "COPYING").  If not, see
!    <http://www.gnu.org/licenses/>.
!
! *****************************************************************

module wind

! *************************************************

!  functions for calculating wind stress 

  use parameters, only : tau_0, sigma, alpha, period
  use analytic, only : i

  implicit none

  contains

! *************************************************

  double precision function wind_stress_x(x,y,t)

! *************************************************

    implicit none

    double precision x,y,t

    wind_stress_x = tau_0*cos(sigma*t)*cos(alpha)

    return

  end function wind_stress_x

! *************************************************

  double precision function wind_stress_y(x,y,t)

! *************************************************

    implicit none

    double precision x,y,t

    wind_stress_y = tau_0*cos(sigma*t)*sin(alpha)

    return

  end function wind_stress_y

! *************************************************

end module wind


